/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2016-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

import { SBasePolylineEdit } from './../../edit/';
import { SGraphItem, SAnchorItem } from "@persagy-web/graph/lib/";
import { Relation } from "./../types/Relation";
import { SMouseEvent, } from "@persagy-web/base/lib";
import { Marker } from '..';
import { SPoint } from "@persagy-web/draw"
/**
 * 编辑基础管道
 *
 * @author 韩耀龙 <han_yao_long@163.com>
 */
export class SBasePipe extends SBasePolylineEdit {
    ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    //属性
    /** 关系型数据 */
    RelationData: Relation;
    /** 起始锚点  */
    startAnchor: SAnchorItem | null = null;
    /** 结束锚点  */
    endAnchor: SAnchorItem | null = null;
    /** 关联锚点1ID  */
    _anchor1ID: string = "";
    get anchor1ID(): string {
        return this._anchor1ID;
    }
    set anchor1ID(v: string) {
        this._anchor1ID = v;
        if (this.data) {
            this.data.Anchor1ID = this._anchor1ID;
        }
    }
    /** 关联锚点2ID  */
    _anchor2ID: string = "";
    get anchor2ID(): string {
        return this._anchor2ID;
    }
    set anchor2ID(v: string) {
        this._anchor2ID = v;
        if (this.data) {
            this.data.Anchor2ID = this._anchor2ID;
        }
    }

    /** 关联节点1ID */
    _node1Id: string = "";
    get node1Id(): string {
        return this._node1Id;
    }
    set node1Id(v: string) {
        this._node1Id = v;
        if (this.data) {
            this.RelationData.node1Id = this._node1Id;
        }
    }

    /** 关联节点2ID */
    _node2Id: string = "";
    get node2Id(): string {
        return this._node2Id;
    }
    set node2Id(v: string) {
        this._node2Id = v;
        if (this.data) {
            this.RelationData.node2Id = this._node2Id;
        }
    }

    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      数据
     */
    constructor(parent: SGraphItem | null, data: Relation) {
        super(parent);
        this.RelationData = data
        const markData: Marker = {
            name: data.name,
            type: "line",
            pos: { x: 0, y: 0 },
            properties: data.properties,
            style: Object.assign(data.style, {
                outLine: data.pointList
            })
        }
        markData.style.default.lineType = data.lineType;
        this.data = markData;
    } // Constructor

    /**
     * 鼠标按下事件
     *
     * @param event   保存事件参数
     * @return 是否处理该事件
     */
    onMouseDown(event: SMouseEvent): boolean {
        super.onMouseDown(event);
        return true;
    } // Function onMouseDown()

    /**
     * 接收事件作出修改
     */
    changePos() {
        if (this.startAnchor) {
            // 判断删除equip后,不移动
            if (this.startAnchor.parent && this.startAnchor.parent.parent) {
                let p = this.startAnchor.mapToScene(0, 0);
                this.pointList[0] = new SPoint(p.x - this.x, p.y - this.y)
            }
        }
        if (this.endAnchor) {
            // 删除equip后
            if (this.endAnchor.parent && this.endAnchor.parent.parent) {
                let p = this.endAnchor.mapToScene(0, 0);
                this.pointList[
                    this.pointList.length - 1
                ] = new SPoint(p.x - this.x, p.y - this.y)
            }
        }
    }
    /**
     * 返回对象储存的相关数据
     *
     * @return 相关数据
     */
    toData(): any {
        return super.toData()
    } // Function toData()
} // Class SBasePipe